@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -691,8 +691,8 @@ static NV_STATUS check_sizes(uvm_gpu_t *gpu)
     if (UVM_PAGE_SIZE_4K >= PAGE_SIZE)
         user_sizes |= UVM_PAGE_SIZE_4K;
 
-    TEST_CHECK_RET(uvm_mmu_user_chunk_sizes(gpu) == user_sizes);
-    TEST_CHECK_RET(uvm_mmu_kernel_chunk_sizes(gpu) == kernel_sizes);
+    TEST_CHECK_RET(gpu->mmu_user_chunk_sizes == user_sizes);
+    TEST_CHECK_RET(gpu->mmu_kernel_chunk_sizes == kernel_sizes);
     return NV_OK;
 }
 
@@ -1619,6 +1619,8 @@ static NV_STATUS fake_gpu_init(NvU32 host_class, NvU32 ce_class, NvU32 architect
     fake_gpu->host_hal = &fake_host_hal;
     fake_gpu->ce_hal = &fake_ce_hal;
 
+    uvm_mmu_init_gpu(fake_gpu);
+
     return NV_OK;
 }
 
