@@ -206,18 +206,21 @@ static bool tracker_is_counter(uvm_tools_event_tracker_t *event_tracker)
     return event_tracker != NULL && !event_tracker->is_queue;
 }
 
-static void put_user_pages(struct page **pages, NvU64 page_count)
+static void uvm_put_user_pages_dirty(struct page **pages, NvU64 page_count)
 {
     NvU64 i;
-    for (i = 0; i < page_count; i++)
+
+    for (i = 0; i < page_count; i++) {
+        set_page_dirty(pages[i]);
         put_page(pages[i]);
+    }
 }
 
 static void unmap_user_pages(struct page **pages, void *addr, NvU64 size)
 {
     size = DIV_ROUND_UP(size, PAGE_SIZE);
     vunmap((NvU8 *)addr);
-    put_user_pages(pages, size);
+    uvm_put_user_pages_dirty(pages, size);
     uvm_kvfree(pages);
 }
 
@@ -281,7 +284,7 @@ fail:
     uvm_kvfree(vmas);
 
     if (ret > 0)
-        put_user_pages(*pages, ret);
+        uvm_put_user_pages_dirty(*pages, ret);
     else if (ret < 0)
         status = errno_to_nv_status(ret);
 
@@ -605,6 +608,9 @@ static long uvm_tools_unlocked_ioctl(struct file *filp, unsigned int cmd, unsign
         UVM_ROUTE_CMD_STACK(UVM_TOOLS_ENABLE_COUNTERS,            uvm_api_tools_enable_counters);
         UVM_ROUTE_CMD_STACK(UVM_TOOLS_DISABLE_COUNTERS,           uvm_api_tools_disable_counters);
     }
+
+    uvm_thread_assert_all_unlocked();
+
     return -EINVAL;
 }
 
@@ -1049,13 +1055,15 @@ void uvm_tools_broadcast_access_counter(uvm_gpu_t *gpu,
     info->eventType           = UvmEventTypeTestAccessCounter;
     info->srcIndex            = gpu->id;
     info->address             = buffer_entry->address.address;
-    info->aperture            = g_hal_to_tools_aperture_table[buffer_entry->address.aperture];
     info->isVirtual           = buffer_entry->address.is_virtual? 1: 0;
     if (buffer_entry->address.is_virtual) {
         info->instancePtr         = buffer_entry->virtual_info.instance_ptr.address;
         info->instancePtrAperture = g_hal_to_tools_aperture_table[buffer_entry->virtual_info.instance_ptr.aperture];
         info->veId                = buffer_entry->virtual_info.ve_id;
     }
+    else {
+        info->aperture            = g_hal_to_tools_aperture_table[buffer_entry->address.aperture];
+    }
     info->isFromCpu           = buffer_entry->counter_type == UVM_ACCESS_COUNTER_TYPE_MOMC? 1: 0;
     info->onManaged           = on_managed? 1 : 0;
     info->value               = buffer_entry->counter_value;
