@@ -1,7 +1,7 @@
 /*
  * _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2006-2013 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2006-2019 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -173,38 +173,6 @@
 #define __NV_RM_LOGON_RC RmLogonRC
 #define NV_REG_RM_LOGON_RC NV_REG_STRING(__NV_RM_LOGON_RC)
 
-/*
- * Option: UpdateMemoryTypes
- *
- * Description:
- *
- * Many kernels have broken implementations of the change_page_attr()
- * kernel interface that may cause cache aliasing problems. Linux/x86-64
- * kernels between 2.6.0 and 2.6.10 may prompt kernel BUG()s due to
- * improper accounting in the interface's large page management code, for
- * example. For this reason, the NVIDIA Linux driver is very careful about
- * not using the change_page_attr() kernel interface on these kernels.
- *
- * Due to the serious nature of the problems that can arise from bugs in
- * the change_page_attr(), set_pages_{uc,wb}() and other kernel interfaces
- * used to modify memory types, the NVIDIA driver implements a manual
- * registry key override to allow forcibly enabling or disabling use of
- * these APIs.
- *
- * Possible values:
- *
- * ~0 = use the NVIDIA driver's default logic (default)
- *  1 = enable use of change_page_attr(), etc.
- *  0 = disable use of change_page_attr(), etc.
- *
- * By default, the NVIDIA driver will attempt to auto-detect if it can
- * safely use the change_page_attr() and other kernel interfaces to modify
- * the memory types of kernel mappings.
- */
-
-#define __NV_UPDATE_MEMORY_TYPES UpdateMemoryTypes
-#define NV_REG_UPDATE_MEMORY_TYPES NV_REG_STRING(__NV_UPDATE_MEMORY_TYPES)
-
 /*
  * Option: InitializeSystemMemoryAllocations
  *
@@ -369,34 +337,6 @@
 #define __NV_REGISTER_FOR_ACPI_EVENTS  RegisterForACPIEvents
 #define NV_REG_REGISTER_FOR_ACPI_EVENTS NV_REG_STRING(__NV_REGISTER_FOR_ACPI_EVENTS)
 
-/*
- * Option: CheckPCIConfigSpace
- *
- * Description:
- *
- * When this option is enabled, the NVIDIA driver will perform checks upon
- * entry to system calls, interrupts and various callbacks to determine
- * if key registers in a given GPU's PCI configuration space, such as
- * the PCI command register and BARs, were altered by third-party
- * software.
- *
- * Possible values:
- *
- *  1 - perform PCI configuration space checks (default on non-virtualized system)
- *  0 - do not perform PCI configuration space checks (default on virtual machine)
- *
- *  Dummy value:
- *  0xFFFFFFFF: It is only used to detect if user has over-ridden the value.
- *              We should never see this value after registry init.
- */
-
-#define __NV_CHECK_PCI_CONFIG_SPACE  CheckPCIConfigSpace
-#define NV_REG_CHECK_PCI_CONFIG_SPACE NV_REG_STRING(__NV_CHECK_PCI_CONFIG_SPACE)
-
-#define NV_CHECK_PCI_CONFIG_SPACE_DISABLED          0
-#define NV_CHECK_PCI_CONFIG_SPACE_ENABLED           1
-#define NV_CHECK_PCI_CONFIG_SPACE_INIT     0xFFFFFFFF
-
 /*
  * Option: AssignGpus
  *
@@ -655,6 +595,60 @@
 #define __NV_RM_PROFILING_ADMIN_ONLY_PARAMETER RestrictProfilingToAdminUsers
 #define NV_REG_RM_PROFILING_ADMIN_ONLY NV_REG_STRING(__NV_RM_PROFILING_ADMIN_ONLY)
 
+/*
+ * Option: TemporaryFilePath
+ *
+ * Description:
+ *
+ * When specified, this option changes the location in which the
+ * NVIDIA kernel module will create unnamed temporary files (e.g. to
+ * save the contents of video memory in).  The indicated file must
+ * be a directory.  By default, temporary files are created in /tmp.
+ */
+#define __NV_TEMPORARY_FILE_PATH TemporaryFilePath
+#define NV_REG_TEMPORARY_FILE_PATH NV_REG_STRING(__NV_TEMPORARY_FILE_PATH)
+
+/*
+ * Option: PreserveVideoMemoryAllocations
+ *
+ * If enabled, this option prompts the NVIDIA kernel module to save and
+ * restore all video memory allocations across system power management
+ * cycles, i.e. suspend/resume and hibernate/restore.  Otherwise,
+ * only select allocations are preserved.
+ *
+ * Possible Values:
+ *
+ *  0: Preserve only select video memory allocations (default)
+ *  1: Preserve all video memory allocations
+ */
+#define __NV_PRESERVE_VIDEO_MEMORY_ALLOCATIONS PreserveVideoMemoryAllocations
+#define NV_REG_PRESERVE_VIDEO_MEMORY_ALLOCATIONS \
+    NV_REG_STRING(__NV_PRESERVE_VIDEO_MEMORY_ALLOCATIONS)
+
+/*
+ * Option: DynamicPowerManagement
+ *
+ * This option controls how aggressively the NVIDIA kernel module will manage
+ * GPU power through kernel interfaces.
+ *
+ * Possible Values:
+ *
+ *  0: Never allow the GPU to be powered down (default).
+ *  1: Power down the GPU when it is not initialized.
+
+
+
+ */
+#define __NV_DYNAMIC_POWER_MANAGEMENT DynamicPowerManagement
+#define NV_REG_DYNAMIC_POWER_MANAGEMENT \
+    NV_REG_STRING(__NV_DYNAMIC_POWER_MANAGEMENT)
+
+#define NV_REG_DYNAMIC_POWER_MANAGEMENT_NEVER   0
+#define NV_REG_DYNAMIC_POWER_MANAGEMENT_COARSE  1
+
+
+
+
 #if defined(NV_DEFINE_REGISTRY_KEY_TABLE)
 
 /*
@@ -668,18 +662,19 @@ NV_DEFINE_REG_ENTRY(__NV_MODIFY_DEVICE_FILES, 1);
 NV_DEFINE_REG_ENTRY(__NV_DEVICE_FILE_UID, 0);
 NV_DEFINE_REG_ENTRY(__NV_DEVICE_FILE_GID, 0);
 NV_DEFINE_REG_ENTRY(__NV_DEVICE_FILE_MODE, 0666);
-NV_DEFINE_REG_ENTRY(__NV_UPDATE_MEMORY_TYPES, ~0);
 NV_DEFINE_REG_ENTRY(__NV_INITIALIZE_SYSTEM_MEMORY_ALLOCATIONS, 1);
 NV_DEFINE_REG_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE, ~0);
 NV_DEFINE_REG_ENTRY(__NV_MAP_REGISTERS_EARLY, 0);
 NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
-NV_DEFINE_REG_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE, NV_CHECK_PCI_CONFIG_SPACE_INIT);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_PCIE_GEN3, 0);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 1);
 NV_DEFINE_REG_ENTRY(__NV_TCE_BYPASS_MODE, NV_TCE_BYPASS_MODE_DEFAULT);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_STREAM_MEMOPS, 0);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_BACKLIGHT_HANDLER, 1);
 NV_DEFINE_REG_ENTRY(__NV_RM_PROFILING_ADMIN_ONLY_PARAMETER, 1);
+NV_DEFINE_REG_ENTRY(__NV_PRESERVE_VIDEO_MEMORY_ALLOCATIONS, 0);
+NV_DEFINE_REG_ENTRY(__NV_DYNAMIC_POWER_MANAGEMENT, 0);
+
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_ENABLE_USER_NUMA_MANAGEMENT, 1);
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_MEMORY_POOL_SIZE, 0);
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_KMALLOC_HEAP_MAX_SIZE, 0);
@@ -691,6 +686,7 @@ NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS_PER_DEVICE, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_RM_MSG, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_GPU_BLACKLIST, NULL);
+NV_DEFINE_REG_STRING_ENTRY(__NV_TEMPORARY_FILE_PATH, NULL);
 
 #if !defined(NV_VMWARE)
 NV_DEFINE_REG_STRING_ENTRY(__NV_ASSIGN_GPUS, NULL);
@@ -715,13 +711,11 @@ nv_parm_t nv_parms[] = {
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_DEVICE_FILE_UID),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_DEVICE_FILE_GID),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_DEVICE_FILE_MODE),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_UPDATE_MEMORY_TYPES),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_INITIALIZE_SYSTEM_MEMORY_ALLOCATIONS),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_MSI),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_MAP_REGISTERS_EARLY),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_PCIE_GEN3),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_MEMORY_POOL_SIZE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_KMALLOC_HEAP_MAX_SIZE),
@@ -734,6 +728,8 @@ nv_parm_t nv_parms[] = {
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_NVLINK_DISABLE),
     NV_DEFINE_PARAMS_TABLE_ENTRY_CUSTOM_NAME(__NV_RM_PROFILING_ADMIN_ONLY,
         __NV_RM_PROFILING_ADMIN_ONLY_PARAMETER),
+    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_PRESERVE_VIDEO_MEMORY_ALLOCATIONS),
+    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_DYNAMIC_POWER_MANAGEMENT),
     {NULL, NULL, NULL}
 };
 
